@@ -15,13 +15,10 @@ package Net::DNS::Resolver::Programmable;
 Net::DNS::Resolver::Programmable - programmable DNS resolver class for offline
 emulation of DNS
 
-=head1 VERSION
-
-0.003
 
 =cut
 
-use version; our $VERSION = qv('0.004');
+our $VERSION = '0.005';
 
 use warnings;
 use strict;
@@ -33,6 +30,11 @@ use Net::DNS::Packet;
 use constant TRUE   => (0 == 0);
 use constant FALSE  => not TRUE;
 
+my %rcode = map { $_ => 1 } qw(NOERROR FORMERR SERVFAIL NXDOMAIN NOTIMP
+        REFUSED YXDOMAIN YXRRSET NXRRSET NOTAUTH NOTZONE BADVERS
+        BADSIG BADKEY BADTIME BADMODE BADNAME BADALG BADTRUNC);
+
+
 # Interface:
 ##############################################################################
 
@@ -205,7 +207,7 @@ sub send {
         ($result, $aa, @answer_rrs) = $resolver_code->($domain, $rr_type, $class);
     }
     
-    if (not defined($result) or defined($Net::DNS::rcodesbyname{$result})) {
+    if ( not defined($result) or defined($rcode{$result}) ) {
         # Valid RCODE, return a packet:
         
         $aa     = TRUE      if not defined($aa);
